import {
  select,
  csv,
  scaleLinear,
  extent,
  scaleBand,
  axisLeft,
  axisBottom,
  format,
  scalePoint
} from 'd3';

const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');

const render = data => {
  const xValue = d =>  d.weight;
  const xAxisLabel = 'Weight'
  const yValue = d =>  d.horsepower ;
  const yAxisLabel = 'Horsepower'
  const margin = { top: 100, right: 40, bottom: 80, left: 200 };
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  const circleRadius = 10;
  const title = 'Cars: Horsepower Vs. Weight';
 
  
  const xScale = scaleLinear()
    .domain(extent(data, xValue))
    .range([0, innerWidth])
    .nice();
  
  const yScale = scaleLinear()
    .domain(extent(data, yValue))
    .range([0, innerHeight])
    .nice();
 
  
  const g = svg.append('g')
    .attr('transform', `translate(${margin.left},${margin.top})`);
  
 
 
  const xAxis = axisBottom(xScale)
    
    .tickSize(-innerHeight)
    .tickPadding(15)
   
  const yAxis = axisLeft(yScale)
    .tickSize(-innerWidth)
    .tickPadding(10);
  
  g.append('g')
    .call(yAxis)
    .selectAll('.domain')
      .remove();
 
  const xAxisG = g.append('g').call(xAxis)
    .attr('transform', `translate(0,${innerHeight})`);
  
  
  const yAxisG = g.append('g').call(yAxis);
  yAxisG.selectAll('.domain').remove(); 
 
    
  xAxisG.append('text')
    .attr('class','xAxis-label')
    .text(xAxisLabel)
    .attr('fill','black')
    .attr('x',innerWidth/2)
    .attr('y',70)

     
  yAxisG.append('text')
    .attr('class','yAxis-label')
    .text(yAxisLabel)
    .attr('fill','black')
    .attr('x',-150)
    .attr('y',-80)
    .attr('transform', `rotate(-90)`)
    .attr('text-anchor', 'middle');
 
  g.selectAll('circle').data(data)
    .enter().append('circle')
      .attr('cy', d => yScale(yValue(d)))
      .attr('cx', d => xScale(xValue(d)))
      .attr('r', circleRadius);
  
  g.append('text')
    .attr('class','title')
    .attr('y',-30)
    .text(title)

  
  
};



csv('https://vizhub.com/curran/datasets/auto-mpg.csv')
  .then(data => {
    data.forEach(d => {
      d.mpg = +d.mpg;
      d.cylinders = +d.cylinders;
      d.displacement = +d.displacement;
      d.horsepower = +d.horsepower;
      d.weight = +d.weight;
      d.acceleration = +d.acceleration;
  });
  render(data);
});